cmoncrawl.common.types.RoutesConfig — CmonCrawl 1.0.0 documentation

Toggle navigation sidebar
Toggle in-page Table of Contents

# cmoncrawl.common.types.RoutesConfig

class cmoncrawl.common.types.RoutesConfig(regexes: list[str] = <factory>, extractors: list[cmoncrawl.common.types.ExtractorConfig] = <factory>)

  Configuration for extractors.

  __init__(regexes: list[str] = <factory>, extractors: list[cmoncrawl.common.types.ExtractorConfig] = <factory>) → None

  Methods

  `__init__`([regexes, extractors]) |
  `from_dict`(kvs, *[, infer_missing]) |
  `from_json`(s, *[, parse_float, parse_int, ...]) |
  `schema`(*[, infer_missing, only, exclude, ...]) |
  `to_dict`([encode_json]) |
  `to_json`(*[, skipkeys, ensure_ascii, ...]) |

  Attributes

  `regexes` |
  `extractors` |